==> bionumpy-0.1.1.tar.gz: bionumpy-0.1.1/bionumpy/datatypes.py <==
import numpy as np
from npstructures import npdataclass, SeqArray

@npdataclass
class RawSeqeuence:
    sequence: SeqArray

@npdataclass
class SequenceEntry:
    name: SeqArray
    sequence: SeqArray


@npdataclass
class SequenceEntryWithQuality:
    name: SeqArray
    sequence: SeqArray
    quality: SeqArray


@npdataclass
class Interval:
    chromosome: SeqArray
    start: np.ndarray
    end: np.ndarray

    def in_interval(self, position):
        return (self.start <= position) & (position < self.end)

    def __plot__(self, plt):
        return [plt.hist(self.end - self.start, name="size"), plt.hist("start")]


@npdataclass
class Variant:
    chromosome: SeqArray
    position: np.ndarray
    ref_seq: SeqArray
    alt_seq: SeqArray

    def is_snp(self):
        return np.logical_and(
            self.ref_seq.shape.lengths == 1, self.alt_seq.shape.lengths == 1
        )

    def __plot__(self, plt):
        return [
            plt.hist("position"),
            plt.bar(
                {
                    "snp": self.is_snp().sum(),
                    "ins": self.is_insertion().sum(),
                    "del": self.is_deletion().sum(),
                }
            ),
            plt.count_matrix(),
        ]


@npdataclass
class VariantWithGenotypes(Variant):
    genotypes: np.ndarray


class SNP(Variant):
    pass


class SortedIntervals:
    def __init__(self, data):
        self.data = np.asanyarray(data)
        assert data.shape[-1] == 2
        assert len(data.shape) == 2

        self.starts = self.data[..., 0]
        self.ends = self.data[..., 1]

    def in_intervals(self, position):
        idx = np.minimum(
            np.searchsorted(self.starts, position, side="left"), self.starts.size - 1
        )
        return (position >= self.starts[idx]) & (position < self.ends[idx])

    @classmethod
    def concatenate(cls, elements):
        return cls(np.vstack([element.data for element in elements]))


@npdataclass
class GFFEntry:
    chromosome: str
    source: str
    feature_type: str
    start: int
    end: int
    score: None
    strand: str
    phase: int
    atributes: str


@npdataclass
class SAMEntry:
    name: str
    flag: int
    chromosome: str
    position: int
    mapq: int
    cigar: str
    next_chromosome: str
    next_position: int
    length: int
    sequence: str
    quality: str

==> bionumpy-0.2.0.tar.gz: bionumpy-0.2.0/bionumpy/datatypes.py <==
import numpy as np
from .encodings import QualityEncoding
from .encodings.base_encoding import CigarEncoding
from .encodings.alphabet_encoding import CigarOpArray, BamArray
from .bnpdataclass import bnpdataclass


@bnpdataclass
class RawSeqeuence:
    sequence: str


@bnpdataclass
class SequenceEntry:
    name: str
    sequence: str


@bnpdataclass
class SequenceEntryWithQuality:
    name: str
    sequence: str
    quality: QualityEncoding


@bnpdataclass
class Interval:
    chromosome: str
    start: int
    end: int


@bnpdataclass
class Bed6(Interval):
    name: str
    score: int
    strand: str


@bnpdataclass
class StrandedInterval(Interval):
    strand: int


@bnpdataclass
class Variant:
    chromosome: str
    position: int
    ref_seq: str
    alt_seq: str


@bnpdataclass
class VariantWithGenotypes(Variant):
    genotypes: int


class SNP(Variant):
    pass


class SortedIntervals:
    def __init__(self, data):
        self.data = np.asanyarray(data)
        assert data.shape[-1] == 2
        assert len(data.shape) == 2

        self.starts = self.data[..., 0]
        self.ends = self.data[..., 1]

    def in_intervals(self, position):
        idx = np.minimum(
            np.searchsorted(self.starts, position, side="left"), self.starts.size - 1
        )
        return (position >= self.starts[idx]) & (position < self.ends[idx])

    @classmethod
    def concatenate(cls, elements):
        return cls(np.vstack([element.data for element in elements]))


@bnpdataclass
class GFFEntry:
    chromosome: str
    source: str
    feature_type: str
    start: int
    end: int
    score: str
    strand: str
    phase: int
    atributes: str


@bnpdataclass
class SAMEntry:
    name: str
    flag: int
    chromosome: str
    position: int
    mapq: int
    cigar: str
    next_chromosome: str
    next_position: int
    length: int
    sequence: str
    quality: str


@bnpdataclass
class BamEntry:
    chromosome: str
    name: str
    flag: int
    position: int
    mapq: int
    cigar_op: CigarOpArray
    cigar_length: CigarEncoding
    sequence: BamArray
    quality: QualityEncoding
